pub type Result<T> = Result<T, CacheError>;Expand description
Convenience alias used across the crate and by consumers.
Aliased Type
pub enum Result<T> {
Ok(T),
Err(CacheError),
}pub type Result<T> = Result<T, CacheError>;Convenience alias used across the crate and by consumers.
pub enum Result<T> {
Ok(T),
Err(CacheError),
}