pub enum LookupResult<T> {
Hit(T),
Invalidated,
Miss,
}Expand description
Result of a cache lookup.
Variants
Hit(T)
Cache hit: the file is unchanged and a payload was stored.
Invalidated
The file changed since it was cached. The stored payload is no longer valid and will be replaced on the next upsert.
Miss
The file is not registered in the cache.