CacheRead

Trait CacheRead 

pub trait CacheRead {
    // Required methods
    fn check(&self, path: &Path) -> Result<bool>;
    fn check_all(&self, paths: &[&Path]) -> Vec<(PathBuf, Result<bool>)>;
    fn list_paths(&self) -> Result<Vec<String>>;
}
Read-side capability shared by the image and video readers.

Required Methods

fn check(&self, path: &Path) -> Result<bool>

true when the cache entry for path exists and is fresh.

fn check_all(&self, paths: &[&Path]) -> Vec<(PathBuf, Result<bool>)>

Batch variant of check, parallelized.

fn list_paths(&self) -> Result<Vec<String>>

Canonicalized paths of every registered entry.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors